package travel.demo.com.umeng_plugin_cai;

import android.app.Activity;
import android.text.TextUtils;
import android.util.Log;

import androidx.annotation.NonNull;

import com.leon.channel.helper.ChannelReaderUtil;
import com.umeng.analytics.MobclickAgent;
import com.umeng.commonsdk.UMConfigure;

import java.util.HashMap;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

/** UmengPluginCaiPlugin */
public class UmengPluginCaiPlugin implements FlutterPlugin, MethodCallHandler, ActivityAware {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private MethodChannel channel;

  private Activity activity;

  @Override
  public void onAttachedToEngine(@NonNull FlutterPlugin.FlutterPluginBinding flutterPluginBinding) {
    channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "umeng_plugin_cai");
    channel.setMethodCallHandler(this);
  }

  @Override
  public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
    switch (call.method) {
      case "init":
        init(call, result);
        break;
      case "getChannel":
        getChannel(result);
        break;
      case "event":
        event(call, result);
        break;
      case "eventMap":
        eventMap(call, result);
        break;
      case "beginLogPageView":
        beginLogPageView(call, result);
        break;
      case "endLogPageView":
        endLogPageView(call, result);
        break;
      case "onResume":
        onResumeActivity(result);
        break;
      case "onPause":
        onPauseActivity(result);
        break;
      default:
        result.notImplemented();
        break;
    }
  }
  public void init(MethodCall call, Result result) {
    boolean logEnable = false;
    if (call.hasArgument("logEnable")) {
      logEnable = call.argument("logEnable");
    }
    UMConfigure.setLogEnabled(logEnable);
    String channel = "flutter";
    if (call.hasArgument("channel")) {
      channel = call.argument("channel");
    }

    UMConfigure.init(activity, (String) call.argument("appKey"), channel, UMConfigure.DEVICE_TYPE_PHONE, null);
    boolean encrypt = false;
    if (call.hasArgument("encrypt")) {
      encrypt = call.argument("encrypt");
    }
    UMConfigure.setEncryptEnabled(encrypt);
    result.success(true);
  }

  private void getChannel(Result result) {
    String channel = ChannelReaderUtil.getChannel(activity);
    if (TextUtils.isEmpty(channel)) {
      channel = "flutter";
    }
    channel = channel.replace("_", "");
    result.success(channel);
  }

  public void event(MethodCall call, Result result) {
    if (call.hasArgument("label")) {
      String label = call.argument("label");
      MobclickAgent.onEvent(activity, (String) call.argument("eventId"), label);
    } else {
      MobclickAgent.onEvent(activity, (String) call.argument("eventId"));
    }
    result.success(true);
  }

  private void eventMap(MethodCall call, Result result) {
    try {
      if (call.hasArgument("map")) {
        HashMap<String, String> jsonMap = call.argument("map");
        MobclickAgent.onEvent(activity, (String) call.argument("eventId"), jsonMap);
      }
      result.success(true);
    } catch (Exception e) {
      e.printStackTrace();
    }

  }

  public void beginLogPageView(MethodCall call, Result result) {
    MobclickAgent.onPageStart((String) call.argument("pageName"));
    result.success(true);
  }

  public void endLogPageView(MethodCall call, Result result) {
    MobclickAgent.onPageEnd((String) call.argument("pageName"));
    result.success(true);
  }

  public void onResumeActivity(Result result) {
    MobclickAgent.onPause(activity);
    result.success(true);
  }

  public void onPauseActivity(Result result) {
    MobclickAgent.onPause(activity);
    result.success(true);
  }


  @Override
  public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
    channel.setMethodCallHandler(null);
  }

  @Override
  public void onAttachedToActivity(@NonNull ActivityPluginBinding binding) {
    activity = binding.getActivity();
    Log.d("123","123");
  }

  @Override
  public void onDetachedFromActivityForConfigChanges() {

  }

  @Override
  public void onReattachedToActivityForConfigChanges(@NonNull ActivityPluginBinding binding) {
    activity = binding.getActivity();
  }

  @Override
  public void onDetachedFromActivity() {

  }
}
